==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hjemmeside',
'articles' => 'Artikler',
'articles_auteur' => 'Denne forfatters artikler',
'articles_populaires' => 'De mest l&aelig;ste artikler',
'articles_rubrique' => 'Dette omr&aring;des artikler',
'aucun_article' => 'Der er ingen artikel p&aring; denne adresse',
'aucun_auteur' => 'Der er ingen forfatter p&aring; denne adresse',
'aucun_site' => 'Der er intet websted p&aring; denne adresse',
'aucune_breve' => 'Der er ingen nyhed p&aring; denne adresse',
'aucune_rubrique' => 'Der er ikke noget afsnit p&aring; denne adresse',
'autres_breves' => 'Andre nyheder',
'autres_groupes_mots_clefs' => 'Andre grupper af n&oslash;gleord',
'autres_sites' => 'Andre websteder',

// B
'bonjour' => 'Hej',
'breves' => 'Nyheder',

// C
'commenter_site' => 'Kommentar til dette websted',

// D
'date' => 'Dato',
'dernier_ajout' => 'Seneste tilf&oslash;jelse',
'dernieres_breves' => 'Seneste nyhed',
'derniers_articles' => 'Seneste artikler',
'derniers_commentaires' => 'Seneste kommentarer',
'derniers_messages_forum' => 'Seneste indl&aelig;g offentliggjort i forummer',

// E
'edition_mode_texte' => 'Tekstudgave',
'en_reponse' => 'Svaradresse:',
'en_resume' => 'Opsummering',
'envoyer_message' => 'Lav indl&aelig;g',
'espace_prive' => 'Privat omr&aring;de',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Webstedets struktur',

// J
'jours' => 'dage',

// M
'meme_auteur' => 'Af samme forfatter',
'meme_rubrique' => 'I samme afsnit',
'memes_auteurs' => 'Af samme forfattere',
'message' => 'Indl&aelig;g',
'messages_forum' => 'Forumindl&aelig;g',
'messages_recents' => 'Seneste forumindl&aelig;g',
'mots_clefs' => 'N&oslash;gleord',
'mots_clefs_meme_groupe' => 'N&oslash;gleord i samme gruppe',

// N
'navigation' => 'Navigering',
'nom' => 'Navn',
'nouveautes' => 'Hvad nyt',
'nouveautes_web' => 'Hvad nyt p&aring; Internettet',
'nouveaux_articles' => 'Nye artikler',
'nouvelles_breves' => 'Nyheder',

// P
'page_precedente' => 'foreg&aring;ende side',
'page_suivante' => 'n&aelig;ste side',
'par_auteur' => 'af',
'participer_site' => 'Du kan deltage aktivt p&aring; dette websted og skrive dine egne artikler ved at tilmelde dig nedenfor. Du vil da straks modtage en email med en adgangskode til webstedets private omr&aring;de.',
'plan_site' => 'Indholdsoversigt',
'popularite' => 'Popularitet',
'poster_message' => 'Indl&aelig;g',

// R
'repondre_article' => 'Lav et svar til denne artikel',
'repondre_breve' => 'Lav et svar p&aring; denne nyhed',
'repondre_message' => 'Lav et svar p&aring; dette indl&aelig;g',
'resultats_recherche' => 'S&oslash;geresultater',
'retour_debut_forums' => 'Tilbage til starten p&aring; forummet',
'rubrique' => 'Afsnit',
'rubriques' => 'Afsnit',

// S
'signatures_petition' => 'Underskrifter',
'site_realise_avec_spip' => 'Websted lavet med SPIP',
'sites_web' => 'Websteder',
'sous_rubriques' => 'Underafsnit',
'suite' => 'forts&aelig;t',
'sur_web' => 'P&aring; Internettet',
'syndiquer_rubrique' => 'Syndiker dette afsnit',
'syndiquer_site' => 'Syndiker hele webstedet',

// T
'texte_lettre_information' => 'Her er webstedets nyhedsbrev',
'texte_lettre_information_2' => 'Dette brev opsummerer artikler og nyheder offentlliggjort siden',

// V
'ver_imprimer' => 'Printbar version',
'voir_en_ligne' => 'Se online',
'voir_squelette' => 'Hent skabelonen til denne side'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hjemmeside',
'article' => 'Article', # NEW
'articles' => 'Artikler',
'articles_auteur' => 'Denne forfatters artikler',
'articles_populaires' => 'De mest l&aelig;ste artikler',
'articles_rubrique' => 'Dette omr&aring;des artikler',
'aucun_article' => 'Der er ingen artikel p&aring; denne adresse',
'aucun_auteur' => 'Der er ingen forfatter p&aring; denne adresse',
'aucun_site' => 'Der er intet websted p&aring; denne adresse',
'aucune_breve' => 'Der er ingen nyhed p&aring; denne adresse',
'aucune_rubrique' => 'Der er ikke noget afsnit p&aring; denne adresse',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Andre nyheder',
'autres_groupes_mots_clefs' => 'Andre grupper af n&oslash;gleord',
'autres_sites' => 'Andre websteder',

// B
'bonjour' => 'Hej',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Nyheder',

// C
'commenter_site' => 'Kommentar til dette websted',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Dato',
'dernier_ajout' => 'Seneste tilf&oslash;jelse',
'dernieres_breves' => 'Seneste nyhed',
'derniers_articles' => 'Seneste artikler',
'derniers_commentaires' => 'Seneste kommentarer',
'derniers_messages_forum' => 'Seneste indl&aelig;g offentliggjort i forummer',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Tekstudgave',
'en_reponse' => 'Svaradresse:',
'en_resume' => 'Opsummering',
'envoyer_message' => 'Lav indl&aelig;g',
'espace_prive' => 'Privat omr&aring;de',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Webstedets struktur',

// J
'jours' => 'dage',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Af samme forfatter',
'meme_rubrique' => 'I samme afsnit',
'memes_auteurs' => 'Af samme forfattere',
'message' => 'Indl&aelig;g',
'messages_forum' => 'Forumindl&aelig;g',
'messages_recents' => 'Seneste forumindl&aelig;g',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'N&oslash;gleord',
'mots_clefs_meme_groupe' => 'N&oslash;gleord i samme gruppe',

// N
'navigation' => 'Navigering',
'nom' => 'Navn',
'nouveautes' => 'Hvad nyt',
'nouveautes_web' => 'Hvad nyt p&aring; Internettet',
'nouveaux_articles' => 'Nye artikler',
'nouvelles_breves' => 'Nyheder',

// P
'page_precedente' => 'foreg&aring;ende side',
'page_suivante' => 'n&aelig;ste side',
'par_auteur' => 'af',
'participer_site' => 'Du kan deltage aktivt p&aring; dette websted og skrive dine egne artikler ved at tilmelde dig nedenfor. Du vil da straks modtage en email med en adgangskode til webstedets private omr&aring;de.',
'plan_site' => 'Indholdsoversigt',
'popularite' => 'Popularitet',
'poster_message' => 'Indl&aelig;g',
'proposer_site' => 'Vous pouvez proposer un site &agrave; ajouter dans cette rubrique&nbsp;:', # NEW

// R
'repondre_article' => 'Lav et svar til denne artikel',
'repondre_breve' => 'Lav et svar p&aring; denne nyhed',
'repondre_message' => 'Lav et svar p&aring; dette indl&aelig;g',
'resultats_recherche' => 'S&oslash;geresultater',
'retour_debut_forums' => 'Tilbage til starten p&aring; forummet',
'rubrique' => 'Afsnit',
'rubriques' => 'Afsnit',

// S
'signatures_petition' => 'Underskrifter',
'site_realise_avec_spip' => 'Websted lavet med SPIP',
'sites_web' => 'Websteder',
'sous_rubriques' => 'Underafsnit',
'spam' => 'Spam', # NEW
'suite' => 'forts&aelig;t',
'sur_web' => 'P&aring; Internettet',
'syndiquer_rubrique' => 'Syndiker dette afsnit',
'syndiquer_site' => 'Syndiker hele webstedet',

// T
'texte_lettre_information' => 'Her er webstedets nyhedsbrev',
'texte_lettre_information_2' => 'Dette brev opsummerer artikler og nyheder offentlliggjort siden',

// V
'ver_imprimer' => 'Printbar version',
'voir_en_ligne' => 'Se online',
'voir_squelette' => 'Hent skabelonen til denne side'
);

?>
